.. _chapter_phase_api:

Chapter: Phase API
==================

In this chapter, we introduce you to the **PyAutoFit** phase API, which long-term software projects can adopt to interface
**PyAutoFit** directly with your software and provide a better management of many of model composition and fitting,
such as visualization, outputting results in a structured format and augmenting data before a fit.

You can start the tutorials right now by going to `our binder <https://notebooks.gesis.org/binder/v2/gh/Jammy2211/autofit_workspace/7586a67b726dca612404cf5fab1d77d8738f3737>`_
and navigating to the folder `notebooks/howtofit/chapter_phase_api`. They are also on the `autofit_workspace <https://github.com/Jammy2211/autofit_workspace>`_.

The chapter contains the following tutorials:

**Tutorial 1: Source Code**
- How the source code of your software project should be structure to best use **PyAutoFit**.

**Tutorial 2: Visualization and Configs**
- How to set up your project to visualize results and use configuration files.

**Tutorial 3: Phase Customization**
- Augmenting the ``data`` and customizing the likelihood function of a model-fit.

**Tutorial 4: Aggregator**
- Designing your project to be exploit **PyAutoFit**'s `Aggregator`.